package at.fhooe.mc.magicwand.client.sensors;

import javax.microedition.location.*;

/**
 * @class GPSReader
 * @author Manuela Vogler
 * @brief Used to get GPS position.
 */
public class GPSReader {

    /**
     * Current longitude
     */
    private double m_longitude;
    /**
     * Current latitude
     */
    private double m_latitude;

    /**
     * @fn public GPSReader()
     * @brief Constructs new GPSReader.
     */
    public GPSReader() {
        m_longitude = 0.0;
        m_latitude = 0.0;
    }

    /**
     * @fn public void updatePosition() throws LocationException, InterruptedException
     * @brief Updates the values for current longitude and latitude.
     * @throws javax.microedition.location.LocationException if no location provider is found or if no location result can be retrieved
     * @throws java.lang.InterruptedException if the operation to get the location is interrupted
     */
    public void updatePosition() throws LocationException,InterruptedException {
        //reset position data
        m_longitude = 0.0;
        m_latitude = 0.0;

        Criteria crit = new Criteria();
        crit.setHorizontalAccuracy(500); //sets the horizontal accurancy to 500 meters

        LocationProvider lp = LocationProvider.getInstance(crit); //uses specified criteria
        Location l = lp.getLocation(15); //get current location, timeout 15 seconds
        Coordinates c = l.getQualifiedCoordinates(); //get coordinates of location
        if (c != null) {
            //store longitude and latitude
            m_latitude = c.getLatitude();
            m_longitude = c.getLongitude();
        }
    }

    /**
     * @fn public double getLongitude()
     * @brief Returns the current longitude.
     * @return The longitude
     */
    public double getLongitude() {
        return m_longitude;
    }

    /**
     * @fn public double getLatitude()
     * @brief Returns the current latitude.
     * @return The latitude
     */
    public double getLatitude() {
        return m_latitude;
    }
}
