/*
 ============================================================================
 Name		: MagicWandCompassReader.h
 Author	  : Manuela Vogler
 Version	 : 1.0
 Copyright   : 
 Description : CMagicWandCompassReader declaration
 ============================================================================
 */

#ifndef COMPASSREADER_H
#define COMPASSREADER_H

// INCLUDES
#include <e32std.h>
#include <e32base.h>
#include <aknappui.h>
#include <akndoc.h>
#include <aknapp.h>
#include <e32property.h>
#include <aknwaitdialog.h>
#include <AknProgressDialog.h>
#include <eikprogi.h>
#include <sensrvchannelfinder.h>
#include <sensrvchannel.h>
#include <sensrvchannelinfo.h>
#include <sensrvmagnetometersensor.h>
#include <sensrvmagneticnorthsensor.h>
#include <sensrvdatalistener.h>

// CLASS DECLARATION

/**
 *  @class CCompassReader CompassReader.h
 *  @brief Receives a callback when new sensor data is available and stores the current compass angle relative to the north.
 *  @author Manuela Vogler
 */
class CCompassReader : public CBase, MSensrvDataListener
	{
public:
	// Constructors and destructor
	~CCompassReader();
	static CCompassReader* NewL();
	static CCompassReader* NewLC();
public:
	//Public functions
	TBool IsRunning();
	TInt GetAngle();
	
protected:
	//Protected functions
	void DataReceived(CSensrvChannel& aChannel, TInt aCount, TInt aDataLost);

	/**
	 * @brief Inherited from MSensrvDataListener. No implementation needed.
	 */
	void GetDataListenerInterfaceL(TUid /*aInterfaceUid*/, TAny*& /*aInterface*/)
		{
		}
	;
	void DataError(CSensrvChannel& aChannel, TSensrvErrorSeverity aError);

private:
	void GetMagneticNorthDataChannelL();
private:
	//Private construction functions
	CCompassReader();
	void ConstructL();
private:
	//Instance variables
	
	/**
	 * Channel finder, used to find magnetic north data channel.
	 */
	CSensrvChannelFinder* iSensrvChannelFinder;

	/**
	 * List for channel infos.
	 */
	RSensrvChannelInfoList iChannelInfoList;

	/**
	 * Sensor channel which provides methods to open and control the magnetic north data channel.
	 */
	CSensrvChannel* iSensrvSensorChannel;

	/**
	 * Shows if CompassReader is running.
	 */
	TBool iIsRunning;

	/**
	 * The current compass angle relative to the north. Value is between 0 and 359 if correct value has been received.
	 */
	TInt iAngle;

	};

#endif // COMPASSREADER_H
